<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=oc_prv
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'activer_plugin' => 'Activar l’ajuston',
	'aide_non_disponible' => 'Aquela part de l’ajuda en linha es pas encara disponibla per aquesta lenga.',
	'auteur' => 'Autor :',
	'avis_acces_interdit' => 'Accès proïbit.',
	'avis_article_modifie' => 'Atencion, @nom_auteur_modif@ a trabalhat sus aquel article fa @date_diff@ minutas',
	'avis_aucun_resultat' => 'Ges de resultat.',
	'avis_chemin_invalide_1' => 'Lo camin qu’avètz chausit',
	'avis_chemin_invalide_2' => 'sembla pas valid. Vougatz tornar a la pagina anteriora per verificar leis informacions fornidas.',
	'avis_connexion_echec_1' => 'La connexion au servidor SQL s’es encalada.', # MODIF
	'avis_connexion_echec_2' => 'Tornatz a la pagina anteriora, e verificatz leis informacions qu’avètz fornidas.',
	'avis_connexion_echec_3' => '<b>N.B.</b> Sus fòrça servidors, devètz <b>demandar</b> qu’activen vòstre accès a la basa SQL avans de la poder utilizar. Se vos podètz pas connectar, verificatz qu’agatz ben realizat aqueu procediment.', # MODIF
	'avis_connexion_ldap_echec_1' => 'La connexion au servidor LDAP s’es encalada.',
	'avis_connexion_ldap_echec_2' => 'Tornatz a la pagina anteriora, e verificatz leis informacions qu’avètz fornidas. ',
	'avis_connexion_ldap_echec_3' => 'Alternativament, utilizetz pas lo supòrt LDAP per importar d’utilizaires.',
	'avis_deplacement_rubrique' => 'Atention! Aquela rubrica conten @contient_breves@ brèvas@scb@: se la desplaçatz, voudretz ben oscar aquela casa de confirmacion.',
	'avis_erreur_connexion_mysql' => 'Error de connexion SQL',
	'avis_espace_interdit' => '<b>Espaci proïbit</b><p>SPIP es ja installat.',
	'avis_lecture_noms_bases_1' => 'Lo programa d’installacion a pas pogut legir lei noms dei basas de donadas installadas.',
	'avis_lecture_noms_bases_2' => 'Siá ges de basa es disponibla, siá la foncion que permet d’entierar lei basas es estada desactivada per de rasons de seguretat (aquò’s lo cas en cò de mai d’un aubergador).',
	'avis_lecture_noms_bases_3' => 'Dins la segonda alternativa, es probable qu’una basa que pòrta vòstre nom de login siá utilizabla:',
	'avis_non_acces_page' => 'Podètz pas accedir a aquela pagina.',
	'avis_operation_echec' => 'L’operacion s’es encalada.',
	'avis_suppression_base' => 'ATENCION, suprimir lei donadas es irreversible',

	// B
	'bouton_acces_ldap' => 'Apondre l’accès a LDAP >>',
	'bouton_ajouter' => 'Apondre',
	'bouton_demande_publication' => 'Demandar la publicacion d’aquest article',
	'bouton_desactive_tout' => 'Desactivar tot',
	'bouton_effacer_tout' => 'O escafar tot',
	'bouton_envoyer_message' => 'Messatge definitiu: mandar',
	'bouton_modifier' => 'Modificar',
	'bouton_radio_afficher' => 'Afichar',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Afichar dins la tiera dei redactors connectats',
	'bouton_radio_envoi_annonces_adresse' => 'Mandar leis anoncis a l’adreiça:',
	'bouton_radio_envoi_liste_nouveautes' => 'Mandar la tiera dei novetats',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Pas aparéisser dins la tiera dei redactors',
	'bouton_radio_non_envoi_annonces_editoriales' => 'Pas mandar d’anoncis editoriaus',
	'bouton_redirection' => 'TORNAR DIRIGIR',
	'bouton_relancer_installation' => 'Tornar lançar l’installacion',
	'bouton_suivant' => 'Seguent',
	'bouton_tenter_recuperation' => 'Assajar de reparar',
	'bouton_test_proxy' => 'Assajar lo proxy',
	'bouton_vider_cache' => 'Vujar l’escondedor',

	// C
	'cache_modifiable_webmestre' => 'Lo webmèstre dau sit pòt modificar aquestei paramètres.',
	'calendrier_synchro' => 'S’utilizatz un logiciau d’agenda compatible <b>iCal</b>, lo podètz sincronizar amb leis informacions d’aquest sit.',

	// D
	'date_mot_heures' => 'oras',

	// E
	'email' => 'e-mail',
	'email_2' => 'e-mail:',
	'entree_adresse_annuaire' => 'Adreiça de l’annuari',
	'entree_adresse_email' => 'Vòstra adreiça e-mail',
	'entree_base_donnee_1' => 'Adreiça de la basa de donadas',
	'entree_base_donnee_2' => '(Sovent, aquela adreiça correspònd a la dau vòstre sit, de còps correspònd a la mençon "localhost", de còps, se laissa vueja completament.)',
	'entree_biographie' => 'Biografia corta, en quauquei mots.',
	'entree_chemin_acces' => '<b>Intrar</b> lo camin d’accès:',
	'entree_cle_pgp' => 'Vòstra clau PGP',
	'entree_contenu_rubrique' => '(Contengut de la rubrica en quauquei mots.)',
	'entree_identifiants_connexion' => 'Vòstreis identificants de connexion...',
	'entree_informations_connexion_ldap' => 'Vougatz intrar dins aqueu formulari leis informacions de connexion au vòstre annuari LDAP.
L’administrator dau sistèma o de la ret vos deu poder fornir
 aqueleis informacions.',
	'entree_infos_perso' => 'Quau siatz?',
	'entree_interieur_rubrique' => 'Dintre la rubrica:',
	'entree_liens_sites' => '<b>Liame ipertèxt</b> (referéncia, sit de vesitar...)',
	'entree_login' => 'Lo vòstre login',
	'entree_login_connexion_1' => 'Lo login de connexion',
	'entree_login_connexion_2' => '(Correspònd de còps au vòstre login d’accès a l’FTP; de còps se laissa vuege)',
	'entree_mot_passe' => 'Vòstre mot de santa Clara',
	'entree_mot_passe_1' => 'Mot de santa Clara per la connexion',
	'entree_mot_passe_2' => '(Correspònd de còps a vòstre mot de santa Clara per l’FTP; de còps se laissa vuege)',
	'entree_nom_fichier' => 'Vougatz intrar lo nom dau fichier @texte_compresse@:',
	'entree_nom_pseudo' => 'Vòstre nom o vòstre pseudonim',
	'entree_nom_pseudo_1' => '(Vòstre nom o vòstre pseudonim)',
	'entree_nom_site' => 'Lo nom dau vòstre sit',
	'entree_nouveau_passe' => 'Mot de santa Clara novèu',
	'entree_passe_ldap' => 'Mot de santa Clara',
	'entree_port_annuaire' => 'Lo numèro de pòrt de l’annuari',
	'entree_signature' => 'Signatura',
	'entree_titre_obligatoire' => '<b>Títol</b> [Obligatòri]<br />',
	'entree_url' => 'L’adreiça (URL) dau vòstre sit',

	// I
	'ical_info1' => 'Aquela pagina mòstra de metòdes diferents per restar en contacte amb la vida d’aqueu sit.',
	'ical_info2' => 'Per tenir mai d’informacions subre aquelei tecnicas, esitetz pas de consultar <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
	'ical_info_calendrier' => 'I a dos calendiers a la vòstra disposicion. Lo primier es un plan dau sit qu’anóncia totei leis articles publicats. Lo segond conten leis anoncis editoriaus en mai de vòstrei darriers messatges privats: vos es reservat gràcias a una clau personala, que la podètz modificar en tot moment en renovant vòstre mot de santa Clara. ',
	'ical_methode_http' => 'Telecargament',
	'ical_methode_webcal' => 'Sincronizacion (webcal://)', # MODIF
	'ical_texte_js' => 'Leis articles publicats en aqueu sit se pòdon afichar aisat, dins totei lei sits vòstres, en fasent servir una linha javascript. ',
	'ical_texte_prive' => 'Aqueu calendier, d’us estrictament personau, vos informa de l’activitat editoriala privada d’aqueu sit (òbras e rendètz-vos personaus, articles e brèvas prepausats...).',
	'ical_texte_public' => 'Aqueu calendier vos permet de seguir l’activitat publica d’aqueu sit (articles e brèvas publicats).',
	'ical_texte_rss' => 'Podètz sindicar lei novetats d’aquest sit dins quin legidor de fichiers que siá en format XML/RSS (Rich Site Summary). Es tanben lo format que permet a SPIP de legir lei novetats publicadas dins d’autrei sits en utilizant un format d’escambi compatible (sits sindicats). ',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Lista de corrier',
	'ical_titre_rss' => 'Fichiers «backend»',
	'icone_activer_cookie' => 'Activar lo cookie de correspondéncia',
	'icone_admin_plugin' => 'Gestion deis ajustons',
	'icone_afficher_auteurs' => 'Afichar leis autors',
	'icone_afficher_visiteurs' => 'Afichar lei vesitaires',
	'icone_arret_discussion' => 'Quitar aquela discussion',
	'icone_calendrier' => 'Calendier',
	'icone_creer_auteur' => 'Crear un autor nòu e l’associar a aquel article',
	'icone_creer_mot_cle' => 'Crear un mot clau nòu e lo liar a aquel article',
	'icone_creer_rubrique_2' => 'Crear una rubrica nòva',
	'icone_modifier_article' => 'Modificar aquel article',
	'icone_modifier_rubrique' => 'Modificar aquela rubrica',
	'icone_retour' => 'Tornar',
	'icone_retour_article' => 'Tornar a l’article',
	'icone_supprimer_cookie' => 'Suprimir lo cookie de correspondéncia',
	'icone_supprimer_rubrique' => 'Suprimir aquela rubrica',
	'icone_supprimer_signature' => 'Suprimir aquela signatura',
	'icone_valider_signature' => 'Validar aquela signatura',
	'image_administrer_rubrique' => 'Podètz administrar aquela rubrica',
	'info_1_article' => '1 article',
	'info_activer_cookie' => 'Podètz activar un <b>cookie de correspondéncia</b>; aquò vos permetrà de passar aisat dau sit public au sit privat.',
	'info_administrateur' => 'Administrator',
	'info_administrateur_1' => 'Administrator',
	'info_administrateur_2' => 'dau sit(<i>d’utilizar amb precaucion</i>)',
	'info_administrateur_site_01' => 'Se siatz administrator/tritz dau sit, vougatz',
	'info_administrateur_site_02' => 'clicar aqueu liame',
	'info_administrateurs' => 'Administrators',
	'info_administrer_rubrique' => 'Podètz administrar aquela rubrica',
	'info_adresse' => 'a l’adreiça:',
	'info_adresse_url' => 'Adreiça (URL) dau sit public',
	'info_aide_en_ligne' => 'Ajuda en linha SPIP',
	'info_ajout_image' => 'Quand apondètz d’imatges coma estacaments jonchs a un article, SPIP pòt crear automaticament per vos de vinhetas (miniaturas) deis imatges inserits. Aquò permet per exemple de crear automaticament una galariá o un pòrtfòlio.',
	'info_ajouter_rubrique' => 'Apondre una autra rubrica d’administrar:',
	'info_annonce_nouveautes' => 'Anonci dei novetats',
	'info_article' => 'article',
	'info_article_2' => 'articles',
	'info_article_a_paraitre' => 'Leis articles pòstdatats per paréisser',
	'info_articles_02' => 'articles',
	'info_articles_2' => 'Articles',
	'info_articles_auteur' => 'Los articles d’aquel autor',
	'info_articles_trouves' => 'Articles trobats',
	'info_attente_validation' => 'Vòstreis articles en espèra de validacion',
	'info_aujourdhui' => 'uei:',
	'info_auteurs' => 'Leis autors',
	'info_auteurs_par_tri' => 'autors@partri@',
	'info_auteurs_trouves' => 'Autors trobats',
	'info_authentification_externe' => 'Autentificacion extèrna',
	'info_avertissement' => 'Avís',
	'info_base_installee' => 'L’estructura de vòstra basa de donadas es installada.',
	'info_chapeau' => 'Capèu',
	'info_chapeau_2' => 'Capèu:',
	'info_chemin_acces_1' => 'Opcions: <b>camin d’accès dins l’annuari</b>',
	'info_chemin_acces_2' => 'Ara devètz configurar lo camin d’accès ais informacions dins l’annuari.',
	'info_chemin_acces_annuaire' => 'Opcions: <b>camin d’accès dins l’annuari',
	'info_choix_base' => 'Tresena estapa:',
	'info_classement_1' => '<sup>ier</sup> de @liste@',
	'info_classement_2' => '<sup>nd</sup> de @liste@',
	'info_code_acces' => 'Oblidetz pas vòstrei còdes d’accès pròpris!',
	'info_config_suivi' => 'S’aquela adreiça correspònd a una lista de corrier, podètz indicar çai sota l’adreiça ont lei participants au sit se pòdon inscriure. Aquela adreiça pòt èstre una URL (per exemple la pagina d’inscripcion a la lista per lo web), o una adreiça e-mail tenent un subjècte especific (per exemple: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Vos podètz abonar a la lista de difusion d’aquest sit. Alora recebretz per e-mail leis anoncis d’articles e de brèvas que se prepausa a la publicacion.',
	'info_confirmer_passe' => 'Confirmar aqueu mot de santa Clara novèu:',
	'info_connexion_base' => 'Segonda estapa: <b>Assai de connexion a la basa</b>',
	'info_connexion_ldap_ok' => 'La connexion LDAP a capitat.</b><p> Podètz passar a l’estapa seguenta.</p>', # MODIF
	'info_connexion_mysql' => 'Primiera estapa: <b>Vòstra connexion SQL</b>',
	'info_connexion_ok' => 'La connexion a capitat.',
	'info_contact' => 'Contacte',
	'info_contenu_articles' => 'Contengut deis articles',
	'info_creation_paragraphe' => '(Per crear de paragrafs, basta que laissetz de linhas vuejas.)', # MODIF
	'info_creation_rubrique' => 'Avans de poder escriure d’articles,<br /> devètz crear aumens una rubrica.<br />',
	'info_creation_tables' => 'Quatrena estapa: <b>Creacion dei taulas de la basa</b>',
	'info_creer_base' => '<b>Crear</b> una basa de donadas novèla:',
	'info_dans_rubrique' => 'Dins la rubrica:',
	'info_date_publication_anterieure' => 'Data anteriora de publicacion:',
	'info_date_referencement' => 'DATA DE REFERENCIAMENT D’AQUEU SIT:',
	'info_derniere_etape' => 'Darriera estapa: <b>Es acabat!',
	'info_descriptif' => 'Descriptiu:',
	'info_discussion_cours' => 'Discussions en cors',
	'info_ecrire_article' => 'Avans de poder escriure d’articles, vos cau crear aumens una rubrica.',
	'info_email_envoi' => 'Adreiça e-mail de mandadís (opcionau)',
	'info_email_envoi_txt' => 'Indicatz aicí l’adreiça d’utilizar per enviar leis e-mails (a fauta d’aquò, s’utilizarà l’adreiça destinatari coma adreiça de mandadís):',
	'info_email_webmestre' => 'Adreiça e-mail dau responsable dau sit (opcionau)', # MODIF
	'info_envoi_email_automatique' => 'Mandadís d’e-mails automatics',
	'info_envoyer_maintenant' => 'Mandar ara',
	'info_etape_suivante' => 'Passar a l’estapa seguenta',
	'info_etape_suivante_1' => 'Podètz passar a l’estapa seguenta.',
	'info_etape_suivante_2' => 'Podètz passar a l’estapa seguenta.',
	'info_exportation_base' => 'exportacion de la basa vèrs @archive@',
	'info_facilite_suivi_activite' => 'Per facilitar lo seguit de l’activitat editoriala dau sit, SPIP vos pòt fornir per e-mail, per exemple a una lista de corrier dei redactors, l’anonci dei demandas de publicacion e dei validacions d’articles.',
	'info_fichiers_authent' => 'Fichiers d’autentificacion « .htpasswd »',
	'info_forums_abo_invites' => 'Vòstre sit web porgís de forums per leis abonats; dins lo sit public lei vesitaires son convidats a se registrar.',
	'info_gauche_admin_tech' => '<b>A aquela pagina, ren que lei responsables dau sit i pòdon accedir.</b><p> Permet de trobar lei diferentei foncions de mantenença tecnica. D’unei que i a implican un procès d’autentificacion especific, que necessita un accès FTP au sit web.</p>', # MODIF
	'info_gauche_admin_vider' => '<b>A aquela pagina, ren que lei responsables dau sit i pòdon accedir.</b><p> Permet de trobar lei diferentei foncions de mantenença tecnica. D’unei que i a implican un procès d’autentificacion especific, que necessita un accès FTP au sit web.</p>', # MODIF
	'info_gauche_auteurs' => 'Trobaretz aicí totei leis autors dau sit. La color deis icònas n’indica l’estatut (administrator = verd; redactor = jaune).',
	'info_gauche_auteurs_exterieurs' => 'Leis autors exteriors, sens accès au sit, son indicats per una icòna blava; leis autors escafats per un bordilhier.', # MODIF
	'info_gauche_messagerie' => 'La messatjariá vos permet d’escambiar de messatges entre redactors, de servar de mementos (per vòstre usatge personau) o d’afichar d’anoncis sus la pagina d’acuelh de l’espaci privat (se siatz administrator/tritz).',
	'info_gauche_statistiques_referers' => 'Aquela pagina presenta la lista dei <i>referidors</i>, valent a dire dei sits que contenon de liames menant vèrs vòstre sit pròpri, mai unicament per ièr e uei: aquela lista s’actualiza cada 24 oras.',
	'info_gauche_visiteurs_enregistres' => 'Trobaretz aquí lei vesitaires registrats
 dins l’espaci public dau sit (forums amb abonament).',
	'info_generation_miniatures_images' => 'Congreacion de miniaturas deis imatges',
	'info_hebergeur_desactiver_envoi_email' => 'D’uneis aubergadors desactivan lo mandadís automatic
 d’e-mails dempuei sei servidors. En aqueu cas, lei foncionalitats seguentas
 d’SPIP foncionaràn pas.',
	'info_hier' => 'ièr:',
	'info_identification_publique' => 'Vòstra identitat publica...',
	'info_image_process' => 'Vougatz seleccionar lo melhor metòde de fabricacion dei vinhetas en clicant sus l’imatge correspondent.',
	'info_image_process2' => '<b>N.B.</b> <i>Se ges d’imatge apareis, aladonc lo servidor qu’aubèrga vòstre sit l’an pas configurat per utilizar d’aisinas talas. Se desiratz d’utilizar aquelei foncions, contactatz lo responsable tecnic e demandatz leis extensions «GD» o «Imagick».</i>', # MODIF
	'info_images_auto' => 'Imatges calculats automaticament',
	'info_informations_personnelles' => 'Cinquena estapa: <b>Informacions personalas</b>',
	'info_inscription_automatique' => 'Inscripcion automatica de redactors novèus',
	'info_jeu_caractere' => 'Jòc de caractèrs dau sit',
	'info_jours' => 'jorns',
	'info_laisser_champs_vides' => 'laissar aquelei camps vueges)',
	'info_langues' => 'Lengas dau sit',
	'info_ldap_ok' => 'L’autentificacion LDAP es installada.',
	'info_lien_hypertexte' => 'Liame ipertèxt:',
	'info_liste_redacteurs_connectes' => 'Tiera dei redactors connectats',
	'info_login_existant' => 'Aqueu login ja existís.',
	'info_login_trop_court' => 'Login tròp cort.',
	'info_maximum' => 'maximum:',
	'info_meme_rubrique' => 'Dins la meteissa rubrica',
	'info_message_en_redaction' => 'Vòstrei messatges en cors de redaccion',
	'info_message_technique' => 'Messatge tecnic:',
	'info_messagerie_interne' => 'Messatjariá intèrna',
	'info_mise_a_niveau_base' => 'Mesa a nivèu de vòstra basa SQL',
	'info_mise_a_niveau_base_2' => '{{Atencion!}} Avètz installada una version
  dei fichiers SPIP {anteriora} a la que i aviá
  avans sus aquest sit: riscatz de pèrdre vòstra basa de donadas
   e vòstre sit foncionarà pus.<br />{{Tornatz installar lei
  fichiers d’SPIP.}}',
	'info_modifier_rubrique' => 'Modificar la rubrica:',
	'info_modifier_titre' => 'Modificar: @titre@',
	'info_mon_site_spip' => 'Mon sit SPIP',
	'info_moyenne' => 'mejana:',
	'info_multi_cet_article' => 'Lenga d’aquest article:',
	'info_multi_langues_choisies' => 'Vougatz seleccionar çai sota lei lengas que son a posita dei redactors de vòstre sit.
  Lei lengas ja emplegadas dins vòstre sit (afichadas d’en primier) se pòdon pas desactivar.',
	'info_multi_secteurs' => '... ren que per lei rubricas a la raiç dau sit?',
	'info_nom' => 'Nom',
	'info_nom_destinataire' => 'Nom dau destinatari',
	'info_nom_site' => 'Nom dau vòstre sit',
	'info_nombre_articles' => '@nb_articles@ articles,',
	'info_nombre_rubriques' => '@nb_rubriques@ rubricas,',
	'info_nombre_sites' => '@nb_sites@ sits,',
	'info_non_deplacer' => 'De pas desplaçar...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP pòt mandar, regularament, l’anonci dei darrierei novetats dau sit
 (articles e brèvas publicats recentament).',
	'info_non_envoi_liste_nouveautes' => 'Pas mandar la tiera dei novetats',
	'info_non_modifiable' => 'se pòt pas modificar',
	'info_non_suppression_mot_cle' => 'vòli pas suprimir aqueu mot clau.',
	'info_notes' => 'Nòtas',
	'info_nouvel_article' => 'Article nòu',
	'info_nouvelle_traduction' => 'Revirada nòva:',
	'info_numero_article' => 'ARTICLE NUMÈRO:',
	'info_obligatoire_02' => '[Obligatòri]', # MODIF
	'info_option_accepter_visiteurs' => 'Acceptar l’inscripcion dei vesitaires dau sit public',
	'info_option_ne_pas_accepter_visiteurs' => 'Refusar l’inscripcion de vesitaires',
	'info_options_avancees' => 'OPCIONS AVANÇADAS',
	'info_ou' => 'o... ',
	'info_page_interdite' => 'Pagina proïbida',
	'info_par_nombre_article' => '(per nombre d’articles)',
	'info_passe_trop_court' => 'Mot de santa Clara tròp cort.',
	'info_passes_identiques' => 'Lei dos mots de santa Clara son pas identics.',
	'info_plus_cinq_car' => 'mai de 5 caractèrs',
	'info_plus_cinq_car_2' => '(mai de 5 caractèrs)',
	'info_plus_trois_car' => '(mai de 3 caractèrs)',
	'info_popularite' => 'popularitat: @popularite@; vesitas: @visites@',
	'info_post_scriptum' => 'Post-scriptum',
	'info_post_scriptum_2' => 'Post-scriptum:',
	'info_pour' => 'per',
	'info_preview_texte' => 'Es possible de previsualizar lo sit coma s’avián publicat totei leis articles e brèvas (que tenon aumens l’estatut "prepausat"). La cau dobrir, aquela possibilitat, ren qu’ais administrators, a totei lei redactors, o en degun?', # MODIF
	'info_procedez_par_etape' => 'procedissètz estapa per estapa',
	'info_procedure_maj_version' => 'Cau lançar la procedura d’actualizacion per adaptar
 la basa de donadas a la version novèla d’SPIP.',
	'info_ps' => 'P.S.',
	'info_publier' => 'publicar',
	'info_publies' => 'Vòstreis articles publicats en linha',
	'info_question_accepter_visiteurs' => 'S’ais esqueletas de vòstre sit web se prevei lo registrament de vesitaires sens accès a l’espaci privat, vougatz activar l’opcion seguenta:',
	'info_question_inscription_nouveaux_redacteurs' => 'Acceptatz que de redactors novèus s’inscrigan
 a partir dau sit public? S’o acceptatz, lei vesitaires se poiràn inscriure
 dieumercé un formulari automatizat e alora accediràn a l’espaci privat per
 prepausar d’articles.<blockquote><i> Durant la fasa d’inscripcion, leis utilizaires recebon un e-mail automatic
 que li baila un còde d’accès au sit privat.
D’uneis aubergadors autorizan pas lo mandadís d’e-mails dempuei sei servidors: en aqueu cas, l’inscripcion automatica es
 impossibla.', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
	'info_racine_site' => 'Raiç dau sit',
	'info_recharger_page' => 'Vougatz tornar cargar aquela pagina dins un momenton.',
	'info_recherche_auteur_zero' => '<b>Ges de resultat trobat per "@cherche_auteur@".',
	'info_recommencer' => 'Vougatz tornar començar.',
	'info_redacteur_1' => 'Redactor',
	'info_redacteur_2' => 'qu’accedís a l’espaci privat (<i>recomandat</i>)',
	'info_redacteurs' => 'Redactors',
	'info_redaction_en_cours' => 'EN CORS DE REDACCION',
	'info_redirection' => 'Redireccion',
	'info_refuses' => 'Vòstreis articles refusats',
	'info_reglage_ldap' => 'Opcions: <b>Reglatge de l’importacion LDAP</b>',
	'info_renvoi_article' => '<b>Redireccion.</b> Aquel article remanda a la pagina:',
	'info_reserve_admin' => 'Ren que leis administrators pòdon modificar aquela adreiça.',
	'info_restreindre_rubrique' => 'Restrénher la gestion a la rubrica:',
	'info_resultat_recherche' => 'Resultats de la cèrca:',
	'info_rubriques' => 'Rubricas',
	'info_rubriques_02' => 'rubricas',
	'info_rubriques_trouvees' => 'Rubricas trobadas',
	'info_sans_titre' => 'Sensa títol',
	'info_selection_chemin_acces' => '<b>Seleccionatz</b> çai sota lo camin d’accès dins l’annuari:',
	'info_signatures' => 'signaturas',
	'info_site' => 'Sit',
	'info_site_2' => 'sit: ',
	'info_site_min' => 'sit',
	'info_site_reference_2' => 'Sit referenciat',
	'info_site_web' => 'SIT WEB:', # MODIF
	'info_sites' => 'sits',
	'info_sites_lies_mot' => 'Lei sits referenciats ligats a aqueu mot clau',
	'info_sites_proxy' => 'Utilizar un proxy',
	'info_sites_trouves' => 'Sits trobats',
	'info_sous_titre' => 'Sostítol:',
	'info_statut_administrateur' => 'Administrator',
	'info_statut_auteur' => 'Estatut d’aquel autor:', # MODIF
	'info_statut_auteur_a_confirmer' => 'Inscripcion de confirmar',
	'info_statut_auteur_autre' => 'Autre estatut :',
	'info_statut_redacteur' => 'Redactor',
	'info_statut_utilisateurs_1' => 'Estatut predefinit deis utilizaires importats',
	'info_statut_utilisateurs_2' => 'Chausissètz l’estatut d’atribuir ai personas presentas dins l’annuari LDAP quora se connèctan per lo primier còp. Poiretz puei modificar aquel estatut per cada autor un cas per un.',
	'info_suivi_activite' => 'Seguit de l’activitat editoriala',
	'info_surtitre' => 'Subretítol:',
	'info_taille_maximale_vignette' => 'Talha maximala dei vinhetas congreadas per lo sistèma:',
	'info_terminer_installation' => 'Ara podètz acabar la procedura d’installacion estandard.',
	'info_texte' => 'Tèxt',
	'info_texte_explicatif' => 'Tèxt explicatiu',
	'info_texte_long' => '(lo tèxt es lòng: apareis doncas en tròç distints que se tornaràn empegar un còp validats.)',
	'info_texte_message' => 'Tèxt dau vòstre messatge:', # MODIF
	'info_texte_message_02' => 'Tèxt dau messatge',
	'info_titre' => 'Títol:',
	'info_total' => 'totau: ',
	'info_tous_articles_en_redaction' => 'Totei leis articles en cors de redaccion',
	'info_tous_articles_presents' => 'Totei leis articles publicats dins aquela rubrica',
	'info_tous_les' => 'totei lei:',
	'info_tout_site' => 'Tot lo sit',
	'info_tout_site2' => 'An pas revirat l’article dins aquela lenga.',
	'info_tout_site3' => 'An revirat l’article dins aquela lenga, mai an portat puei de modificacions a l’article de referéncia. Cau actualizar la revirada.',
	'info_tout_site4' => 'An revirat l’article dins aquela lenga, e la revirada es actualizada.',
	'info_tout_site5' => 'Article originau.',
	'info_tout_site6' => '<b>Atencion:</b> ren que leis articles originaus s’afichan.
Lei reviradas s’assòcian a l’originau,
una color indica lor estat:',
	'info_travail_colaboratif' => 'Trabalh collaboratiu subre leis articles',
	'info_un_article' => 'un article, ',
	'info_un_site' => 'un sit, ',
	'info_une_rubrique' => 'una rubrica, ',
	'info_une_rubrique_02' => '1 rubrica',
	'info_url' => 'URL:',
	'info_urlref' => 'Liame ipertèxt:',
	'info_utilisation_spip' => 'Ara podètz començar d’utilizar lo sistèma de publicacion assistida...',
	'info_visites_par_mois' => 'Afichatge per mes:',
	'info_visiteur_1' => 'Vesitaire',
	'info_visiteur_2' => 'dau sit public',
	'info_visiteurs' => 'Vesitaires',
	'info_visiteurs_02' => 'Vesitaires dau sit public',
	'install_echec_annonce' => 'L’installacion capitarà mau, o abotirà a un sit non foncionau...',
	'install_extension_mbstring' => 'SPIP fonciona pas amb:',
	'install_extension_php_obligatoire' => 'SPIP exigís l’extension php:',
	'install_select_langue' => 'Seleccionatz una lenga puei clicatz lo boton «seguent» per amodar la procedura d’installacion.',
	'intem_redacteur' => 'redactor',
	'item_accepter_inscriptions' => 'Acceptar leis inscripcions',
	'item_activer_messages_avertissement' => 'Activar lei messatges d’avertiment',
	'item_administrateur_2' => 'administrator',
	'item_afficher_calendrier' => 'Afichar dins lo calendier',
	'item_choix_administrateurs' => 'leis administrators',
	'item_choix_generation_miniature' => 'Congrear automaticament lei miniaturas deis imatges.',
	'item_choix_non_generation_miniature' => 'Congrear ges de miniaturas deis imatges.',
	'item_choix_redacteurs' => 'lei redactors',
	'item_choix_visiteurs' => 'lei vesitaires dau sit public',
	'item_creer_fichiers_authent' => 'Crear de fichiers .htpasswd',
	'item_login' => 'Login',
	'item_mots_cles_association_articles' => 'ais articles',
	'item_mots_cles_association_rubriques' => 'ai rubricas',
	'item_mots_cles_association_sites' => 'ai sits referenciats o sindicats',
	'item_non' => 'Non',
	'item_non_accepter_inscriptions' => 'Pas acceptar leis inscripcions',
	'item_non_activer_messages_avertissement' => 'Ges de messatge d’avertiment',
	'item_non_afficher_calendrier' => 'De pas afichar dins lo calendier',
	'item_non_creer_fichiers_authent' => 'Pas crear aquelei fichiers',
	'item_non_publier_articles' => 'Pas publicar leis articles avans la data de publicacion prevista.',
	'item_nouvel_auteur' => 'Autor nòu',
	'item_nouvelle_rubrique' => 'Rubrica nòva',
	'item_oui' => 'Òc',
	'item_publier_articles' => 'Publicar leis articles, quina que siá sa data de publicacion',
	'item_reponse_article' => 'Respònsa a l’article',
	'item_visiteur' => 'vesitaire',

	// J
	'jour_non_connu_nc' => 'n.c.',

	// L
	'lien_ajouter_auteur' => 'Apondre aquel autor',
	'lien_email' => 'e-mail',
	'lien_nom_site' => 'NOM DAU SIT:',
	'lien_retirer_auteur' => 'Levar l’autor',
	'lien_site' => 'sit',
	'lien_tout_deplier' => 'Desplegar tot',
	'lien_tout_replier' => 'Tornar plegar',
	'lien_trier_nom' => 'Triar per nom',
	'lien_trier_nombre_articles' => 'Triar per nombre d’articles',
	'lien_trier_statut' => 'Triar per estatut',
	'lien_voir_en_ligne' => 'VEIRE EN LINHA:',
	'logo_article' => 'LÒGO DE L’ARTICLE', # MODIF
	'logo_auteur' => 'LÒGO DE L’AUTOR', # MODIF
	'logo_rubrique' => 'LÒGO DE LA RUBRICA', # MODIF
	'logo_site' => 'LÒGO D’AQUEU SIT', # MODIF
	'logo_standard_rubrique' => 'LÒGO ESTANDARD DEI RUBRICAS', # MODIF
	'logo_survol' => 'LÒGO PER LO SUBREVÒU', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'Chausida de vòstra basa',
	'module_fichier_langue' => 'Fichier de lenga',
	'module_raccourci' => 'Acorcha',
	'module_texte_affiche' => 'Tèxt afichat',
	'module_texte_explicatif' => 'Podètz inserir leis acorchas seguentas dins leis esqueletas de vòstre sit public. Se reviraràn automaticament  dins lei diferentei lengas per lei qualas existís un fichier de lenga.',
	'module_texte_traduction' => 'Lo fichier de lenga «@module@» es disponible en:',
	'mois_non_connu' => 'non conegut',

	// O
	'onglet_repartition_actuelle' => 'd’aquesta passa',

	// P
	'plugin_etat_developpement' => 'en cors de desvolopament',
	'plugin_etat_experimental' => 'experimentau',
	'plugin_etat_stable' => 'estable',
	'plugin_etat_test' => 'a l’ensag',
	'plugins_liste' => 'Tièra deis ajustons',

	// R
	'repertoire_plugins' => 'Repertòri :',
	'required' => '[Obligatòri]', # MODIF

	// S
	'statut_admin_restreint' => '(admin. restrench)', # MODIF

	// T
	'taille_cache_image' => 'Leis imatges qu’SPIP a calculat automaticament (vinhetas dei documents, títols presentats en forma grafica, foncions matematicas en format TeX...) ocupan dins lo repertòri @dir@ un totau de @taille@.',
	'taille_cache_infinie' => 'Aqueu sit prevei ges de limitacion de talha dau repertòri <code>CACHE/</code>.',
	'taille_cache_maxi' => 'SPIP assaja de limitar la talha dau repertòri <code>CACHE/</code> d’aqueu sit a <b>@octets@</b> de donadas aperaquí.',
	'taille_cache_octets' => 'Ara la talha de l’escondedor compassa @octets@.', # MODIF
	'taille_cache_vide' => 'L’escondedor es vuege.',
	'taille_repertoire_cache' => 'Talha dau repertòri escondedor',
	'text_article_propose_publication' => 'Article prepausat per la publicacion. Esitetz pas de donar vòstre vejaire gràcias au forum estacat a aquel article (en bas de pagina).', # MODIF
	'texte_acces_ldap_anonyme_1' => 'D’unei servidors LDAP accèptan ges d’accès anonim. En aqueu cas, cau especificar un identificant d’accès iniciau per poder puei cercar d’informacions dins l’annuari. Pasmens, lei camps seguents se poiràn laissar vueges dins la màger part dei cas.',
	'texte_admin_effacer_01' => 'Aquela comanda escafa <i>tot</i> lo contengut de la basa de donadas,
 inclús <i>totei</i> leis accès redactors e administrators. Un còp que l’auretz executada, auretz de tornar lançar l’installacion d’SPIP per tornar crear una basa novèla e mai un primier accès administrator.',
	'texte_adresse_annuaire_1' => '(Se vòstre annuari es installat sus la meteissa maquina qu’aqueu sit web, s’agís probable de "localhost".)',
	'texte_ajout_auteur' => 'L’autor seguent es estat apondut a l’article:',
	'texte_annuaire_ldap_1' => 'S’accedissètz a un annuari (LDAP), lo podètz utilizar per importar automaticament d’utilizaires sota SPIP.',
	'texte_article_statut' => 'Aquel article es:',
	'texte_article_virtuel' => 'Article virtuau',
	'texte_article_virtuel_reference' => '<b>Article virtuau:</b> article referenciat dins vòstre sit SPIP, mai redirigit vèrs una autra URL. Per suprimir la redireccion, escafatz l’URL çai subre.',
	'texte_aucun_resultat_auteur' => 'Ges de resultat per "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Aquest sit vos pòt indicar de contunha la tiera dei redactors connectats, çò que vos permet d’escambiar de messatges en dirècte. Podètz decidir de pas aparéisser dins aquela lista (siatz "invisible/a" per leis autreis utilizaires).',
	'texte_auteurs' => 'LEIS AUTORS',
	'texte_choix_base_1' => 'Chausissètz vòstra basa:',
	'texte_choix_base_2' => 'Lo servidor SQL conten mai d’una basa de donadas.',
	'texte_choix_base_3' => '<b>Chausissètz</b> çai sota la que vòstre aubergador vos a atribuida:',
	'texte_compte_element' => '@count@ element',
	'texte_compte_elements' => '@count@ elements',
	'texte_connexion_mysql' => 'Consultatz leis informacions que vòstre aubergador fornís: i devètz trobar, se vòstre aubergador supòrta SQL, lei còdes de connexion au servidor SQL.', # MODIF
	'texte_contenu_article' => '(Contengut de l’article en quauquei mots.)',
	'texte_contenu_articles' => 'Segon la maqueta que vòstre sit a adoptada, podètz decidir
 que certaneis elements deis articles s’utilizen pas.
 Utilizatz la tiera çai sota per indicar quineis elements son disponibles.',
	'texte_crash_base' => 'Se vòstra basa de donadas s’es
 encalada, podètz assajar una reparacion
 automatica.',
	'texte_creer_rubrique' => 'Avans de poder escriure d’articles,<br /> devètz crear una rubrica.',
	'texte_date_creation_article' => 'DATA DE CREACION DE L’ARTICLE:',
	'texte_date_publication_anterieure' => 'DATA DE PUBLICACION ANTERIORA :',
	'texte_date_publication_anterieure_nonaffichee' => 'Afichar ges de data de publicacion anteriora.',
	'texte_date_publication_article' => 'DATA DE PUBLICACION EN LINHA :',
	'texte_descriptif_rapide' => 'Descriptiu rapid',
	'texte_effacer_base' => 'Escafar la basa de donadas SPIP',
	'texte_en_cours_validation' => 'Se prepausa de publicar leis articles e brèvas çai sota. Esitetz pas de donar vòstre vejaire gràcias ai forums que i son estacats.', # MODIF
	'texte_enrichir_mise_a_jour' => 'Podètz enriquir la compaginacion de vòstre tèxt en utilizant d’"acorchas tipograficas".',
	'texte_fichier_authent' => '<b>Deu crear, SPIP, de fichiers especiaus  <tt>.htpasswd</tt>
  e <tt>.htpasswd-admin</tt> dins lo repertòri @dossier@?</b><p>
  Aquelei fichiers vos pòdon servir per restrénher l’accès ais autors
  e administrators alhors dins vòstre sit
  (programa extèrne d’estadisticas, per exemple).<p>
 Se vos sèrv pas, podètz laissar aquesta opcion
  a sa valor predefinida (ges de creacion
  dei fichiers).</p>', # MODIF
	'texte_informations_personnelles_1' => 'Ara lo sistèma vos crearà un accès personalizat au sit.',
	'texte_informations_personnelles_2' => '(Nòta: se s’agís d’una reïnstallacion, e se vòstre accès fonciona encara, podètz', # MODIF
	'texte_introductif_article' => '(Tèxt introductiu de l’article.)',
	'texte_jeu_caractere' => 'Aquesta opcion es utila se vòstre sit deu afichar d’alfabets
 diferents de l’alfabet latin (o "occidentau") e sei derivats.
 En aqueu cas, cau cambiar lo reglatge predefinit per fin d’utilizar
 un jòc de caractèrs apropriat. Oblidetz pas tanpauc d’adaptar
 lo sit public en consequéncia (balisa <tt>#CHARSET</tt>).',
	'texte_jeu_caractere_3' => 'Vòstre sit es per ara installat amb lo jòc de caractèrs :',
	'texte_login_ldap_1' => '(Laissar vuege per un accès anonim, o picar lo camin complet, per exemple «<tt>uid=fabre, ou=usanciers, dc=mon-domeni, dc=com</tt>».)',
	'texte_login_precaution' => 'Atencion! Aquò’s lo login amb lo quau siatz ara connectat/ada. 
 Utilizatz aquest formulari amb precaucion...',
	'texte_mise_a_niveau_base_1' => 'Venètz d’actualizar lei fichiers SPIP.
 Ara cau metre a nivèu la basa de donadas
 dau sit.',
	'texte_modifier_article' => 'Modificar l’article:',
	'texte_multilinguisme' => 'Se desiratz de gerir d’articles en mai d’una lenga, amb una navigacion complèxa, podètz apondre un menut per chausir la lenga deis articles e/o dei rubricas, en foncion de l’organizacion de vòstre sit.', # MODIF
	'texte_multilinguisme_trad' => 'Podètz tanben activar un sistèma de gestion dei liames entre lei diferentei reviradas d’un article.', # MODIF
	'texte_non_compresse' => '<i>non comprimit</i> (per amòr que vòstre servidor supòrta pas aquela foncionalitat)',
	'texte_nouvelle_version_spip_1' => 'Avètz installada una version novèla d’SPIP.',
	'texte_nouvelle_version_spip_2' => 'Aquesta version novèla demanda una actualizacion mai completa que de costuma. Se siatz webmèstre/webmèstra dau sit, vougatz escafar lo fichier <tt>inc_connect.php3</tt> dau repertòri <tt>ecrire</tt> e tornar prene l’installacion per fin d’actualizar vòstrei paramètres de connexion a la basa de donadas.<p> (NB: s’avètz demembrat vòstrei paramètres de connexion, espepissatz lo fichier  <tt>inc_connect.php3</tt> avans de lo suprimir...)</p>', # MODIF
	'texte_operation_echec' => 'Tornatz a la pagina precedenta, chausissètz una autra basa o creatz-ne’n una novèla. Verificatz leis informacions que vòstre aubergador a fornidas.',
	'texte_plus_trois_car' => 'mai de 3 caractèrs',
	'texte_plusieurs_articles' => 'Mai d’un autor trobat per "@cherche_auteur@":',
	'texte_port_annuaire' => '(La valor indicada coma predefinida conven en generau.)',
	'texte_proposer_publication' => 'Quora auretz acabat vòstre article,<br /> poiretz prepausar que siá publicat.',
	'texte_proxy' => 'Dins d’unei cas (intranet, rets protegidas...),
  se pòt que cauga utilizar un <i>proxy HTTP</i> per aténher lei sits sindicats.
  En aqueu cas, marcatz çai sota son adreiça, sota la forma
  <tt><html>http://proxy:8080</html></tt>. En generau,
  laissaretz vueja aquela casa.',
	'texte_publication_articles_post_dates' => 'Coma SPIP se deu comportar fàcia ais articles que sa
  data de publicacion es fixada a una 
  escasença futura?',
	'texte_rappel_selection_champs' => '[Oblidetz pas de seleccionar aqueu camp correctament.]',
	'texte_recalcul_page' => 'Se volètz
tornar calcular ren qu’una pagina, passatz puslèu per l’espaci public e utilizatz lo  boton "tornar calcular".',
	'texte_recuperer_base' => 'Reparar la basa de donadas',
	'texte_reference_mais_redirige' => 'article referenciat dins vòstre sit SPIP, mai redirigit vèrs una autra URL.',
	'texte_requetes_echouent' => '<b>Quora d’unei requistas SQL s’encalan
  sistematicament e sensa rason aparenta, se pòt
  qu’aquò venga ben de la basa de donadas.  </b><p>
  SQL ten la facultat de reparar sei
  taulas quora un accident leis
  a esquintadas. Aicí podètz assajar aquela reparacion; se 
  capita pas, servatz una còpia de l’afichatge, que conten
 benlèu d’indicis de çò que va pas...</p><p>
  Se lo problèma persistís, contactatz vòstre
  aubergador.</p>', # MODIF
	'texte_selection_langue_principale' => 'Podètz seleccionar çai sota la "lenga principala" dau sit. Aquela chausida vos obliga pas -grand gaug- d’escriure vòstreis articles dins la lenga seleccionada, mai permet de determinar:
 <ul><li> lo format predefinit dei datas sus lo sit public;</li>
 <li> la natura dau motor tipografic que SPIP deu utilizar per lo rendut dei tèxts;</li>
 <li> la lenga utilizada dins lei formularis dau sit public;</li>
 <li> la lenga presentada coma predefinida dins l’espaci privat.</li></ul>',
	'texte_sous_titre' => 'Sostítol',
	'texte_statistiques_visites' => '(barras escuras:  dimenge / corba escura: evolucion de la mejana)',
	'texte_statut_attente_validation' => 'en espèra de validacion',
	'texte_statut_publies' => 'publicats en linha',
	'texte_statut_refuses' => 'refusats',
	'texte_suppression_fichiers' => 'Utilizatz aquela comanda per suprimir totei lei fichiers que se tròban
dins l’escondedor SPIP. Aquò permet per exemple de forçar un calcul nòu de totei lei paginas
s’avètz bravament modificat lo grafisme o l’estructura dau sit.',
	'texte_sur_titre' => 'Subretítol',
	'texte_table_ok' => ': aquesta taula es condrecha.',
	'texte_tentative_recuperation' => 'Assai de reparacion',
	'texte_tenter_reparation' => 'Assajar de reparar la basa de donadas',
	'texte_test_proxy' => 'Per assajar aqueu proxy, indicatz aicí l’adreiça d’un sit web
    que lo voudriatz esprovar.',
	'texte_titre_02' => 'Títol:',
	'texte_titre_obligatoire' => '<b>Títol</b> [Obligatòri]',
	'texte_travail_article' => '@nom_auteur_modif@ a trabalhat sus aquel article fa @date_diff@ minutas',
	'texte_travail_collaboratif' => 'Quora es frequent que mai d’un redactor 
  trabalhe sus lo meteis article, lo sistèma
  pòt afichar leis articles recentament "dobèrts"
  per fin d’evitar lei modificacions simultanèas.
  Aquela opcion es desactivada de maniera predefinida
  per fin d’evitar d’afichar de messatges d’avertiment
  intempestius.',
	'texte_vide' => 'vuege',
	'texte_vider_cache' => 'Vujar l’escondedor',
	'titre_admin_tech' => 'Mantenença tecnica',
	'titre_admin_vider' => 'Mantenença tecnica',
	'titre_cadre_afficher_article' => 'Afichar leis articles',
	'titre_cadre_afficher_traductions' => 'Afichar l’estat dei reviradas per aquela lenga',
	'titre_cadre_ajouter_auteur' => 'APONDRE UN AUTOR:',
	'titre_cadre_interieur_rubrique' => 'Dintre la rubrica',
	'titre_cadre_numero_auteur' => 'AUTOR NUMÈRO',
	'titre_cadre_signature_obligatoire' => '<b>Signatura</b> [Obligatòria]<br />',
	'titre_config_fonctions' => 'Configuracion dau sit',
	'titre_configuration' => 'Configuracion dau sit',
	'titre_connexion_ldap' => 'Opcions: <b>Vòstra connexion LDAP</b>',
	'titre_groupe_mots' => 'GROP DE MOTS:',
	'titre_langue_article' => 'LENGA DE L’ARTICLE', # MODIF
	'titre_langue_rubrique' => 'LENGA DE LA RUBRICA', # MODIF
	'titre_langue_trad_article' => 'LENGA E REVIRADAS DE L’ARTICLE',
	'titre_les_articles' => 'LEIS ARTICLES',
	'titre_naviguer_dans_le_site' => 'Navigar per lo sit...',
	'titre_nouvelle_rubrique' => 'Rubrica novèla',
	'titre_numero_rubrique' => 'RUBRICA NUMÈRO:',
	'titre_page_articles_edit' => 'Modificar: @titre@',
	'titre_page_articles_page' => 'Leis articles',
	'titre_page_articles_tous' => 'Tot lo sit',
	'titre_page_calendrier' => 'Calendier @nom_mois@ de @annee@',
	'titre_page_config_contenu' => 'Configuracion dau sit',
	'titre_page_delete_all' => 'supression totala e irreversibla',
	'titre_page_recherche' => 'Resultats de la cèrca @recherche@',
	'titre_page_statistiques_referers' => 'Estadisticas (liames intrants)',
	'titre_page_upgrade' => 'Mesa a nivèu d’SPIP',
	'titre_publication_articles_post_dates' => 'Publicacion deis articles pòstdatats',
	'titre_reparation' => 'Reparacion',
	'titre_suivi_petition' => 'Seguit dei peticions',
	'trad_article_traduction' => 'Totei lei versions d’aquel article:',
	'trad_delier' => 'Cessar de liar aquest article a sei reviradas ', # MODIF
	'trad_lier' => 'Aquest article es una revirada de l’article numèro:',
	'trad_new' => 'Escriure una revirada novèla d’aquest article', # MODIF

	// V
	'version' => 'Version :'
);

?>
